==> file4life-1.1.0-source.tgz: file4life-1.1.0/src/F4L/F4LMonad.hs <==
{- This file is part of file4life, a file backup program written in Haskell.
 - file4life is Copyright (C) Antonio Bellezza 2014
 - file4life is free software: you can redistribute it and/or modify
 - it under the terms of the GNU General Public License as published by
 - the Free Software Foundation, either version 3 of the License, or
 - (at your option) any later version.

 - file4life is distributed in the hope that it will be useful,
 - but WITHOUT ANY WARRANTY; without even the implied warranty of
 - MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 - GNU General Public License for more details.

 - You should have received a copy of the GNU General Public License
 - along with file4life.  If not, see <http://www.gnu.org/licenses/>.
 -}
-- {-# LANGUAGE TemplateHaskell #-}

module F4L.F4LMonad where

import F4L
import F4L.Op

import Control.Lens
import Control.Monad.State.Strict
import Data.Functor((<$>))
import Data.Map.Strict( Map )


type GenF4LMonad k s m = StateT ( F4LState k s ) m

type F4LMonad k m = GenF4LMonad k ActiveSession m

type TopF4LMonad k m = GenF4LMonad k () m

data VerbosityLevel = Quiet | Timid | Chatty | SayAll
                    deriving ( Eq, Show, Ord, Enum )

data Verbosity = Verbosity {
    verb_level :: VerbosityLevel
  , verb_tracing :: Bool
  } deriving Show


data Interactivity = Ask | UseDefault | Use String
                   deriving ( Eq, Show )

data ActiveSession = ActiveSession {
    _as_envid :: !EnvironmentId
  , _as_time :: !TimeStamp
  } deriving Show

st_time :: Lens' ( F4LState k ActiveSession ) TimeStamp
st_time = st_session . as_time

st_envid :: Lens' ( F4LState k ActiveSession ) EnvironmentId
st_envid = st_session . as_envid

-- makeLenses ''ActiveSession

as_envid :: Lens' ActiveSession EnvironmentId
as_envid = lens _as_envid ( \ s a -> s { _as_envid = a } )
{-# INLINE as_envid #-}
as_time :: Lens' ActiveSession TimeStamp
as_time = lens _as_time ( \ s a -> s { _as_time = a } )
{-# INLINE as_time #-}



data F4LState k s = F4LState { 
    _conf_db :: !MetaDB
  , _st_verbosity :: !Verbosity
  , _st_interactive :: !Interactivity
  , _st_withExif :: !Bool
  , _st_withRescan :: !Bool
  , _st_opEnv :: !OpEnv
  , _st_session :: s
  , _st_storages :: !(Map FilePath ( Maybe StorageId )) -- ^ for current session
  , _st_debugCounter :: !Int -- ^ to activate behaviours every n iterations
  , _st_knowledge :: !k
  } deriving Show

-- makeLenses ''F4LState

conf_db ::
  Lens' (F4LState k_a90g s_a90h) MetaDB
conf_db
  _f_a9ty
  (F4LState __conf_db'_a9tz
            __st_verbosity_a9tB
            __st_interactive_a9tC
            __st_withExif_a9tD
            __st_withRescan_a9tE
            __st_opEnv_a9tF
            __st_session_a9tG
            __st_storages_a9tH
            __st_debugCounter_a9tI
            __st_knowledge_a9tJ)
  = ((\ __conf_db_a9tA
        -> F4LState
             __conf_db_a9tA
             __st_verbosity_a9tB
             __st_interactive_a9tC
             __st_withExif_a9tD
             __st_withRescan_a9tE
             __st_opEnv_a9tF
             __st_session_a9tG
             __st_storages_a9tH
             __st_debugCounter_a9tI
             __st_knowledge_a9tJ)
     <$> (_f_a9ty __conf_db'_a9tz))
{-# INLINE conf_db #-}
st_debugCounter ::
  Lens' (F4LState k_a90g s_a90h) Int
st_debugCounter
  _f_a9tK
  (F4LState __conf_db_a9tL
            __st_verbosity_a9tM
            __st_interactive_a9tN
            __st_withExif_a9tO
            __st_withRescan_a9tP
            __st_opEnv_a9tQ
            __st_session_a9tR
            __st_storages_a9tS
            __st_debugCounter'_a9tT
            __st_knowledge_a9tV)
  = ((\ __st_debugCounter_a9tU
        -> F4LState
             __conf_db_a9tL
             __st_verbosity_a9tM
             __st_interactive_a9tN
             __st_withExif_a9tO
             __st_withRescan_a9tP
             __st_opEnv_a9tQ
             __st_session_a9tR
             __st_storages_a9tS
             __st_debugCounter_a9tU
             __st_knowledge_a9tV)
     <$> (_f_a9tK __st_debugCounter'_a9tT))
{-# INLINE st_debugCounter #-}
st_interactive ::
  Lens' (F4LState k_a90g s_a90h) Interactivity
st_interactive
  _f_a9tW
  (F4LState __conf_db_a9tX
            __st_verbosity_a9tY
            __st_interactive'_a9tZ
            __st_withExif_a9u1
            __st_withRescan_a9u2
            __st_opEnv_a9u3
            __st_session_a9u4
            __st_storages_a9u5
            __st_debugCounter_a9u6
            __st_knowledge_a9u7)
  = ((\ __st_interactive_a9u0
        -> F4LState
             __conf_db_a9tX
             __st_verbosity_a9tY
             __st_interactive_a9u0
             __st_withExif_a9u1
             __st_withRescan_a9u2
             __st_opEnv_a9u3
             __st_session_a9u4
             __st_storages_a9u5
             __st_debugCounter_a9u6
             __st_knowledge_a9u7)
     <$> (_f_a9tW __st_interactive'_a9tZ))
{-# INLINE st_interactive #-}
st_knowledge ::
  Lens (F4LState k_a90g s_a90h) (F4LState k_a9u8 s_a90h) k_a90g k_a9u8
st_knowledge
  _f_a9u9
  (F4LState __conf_db_a9ua
            __st_verbosity_a9ub
            __st_interactive_a9uc
            __st_withExif_a9ud
            __st_withRescan_a9ue
            __st_opEnv_a9uf
            __st_session_a9ug
            __st_storages_a9uh
            __st_debugCounter_a9ui
            __st_knowledge'_a9uj)
  = ((\ __st_knowledge_a9uk
        -> F4LState
             __conf_db_a9ua
             __st_verbosity_a9ub
             __st_interactive_a9uc
             __st_withExif_a9ud
             __st_withRescan_a9ue
             __st_opEnv_a9uf
             __st_session_a9ug
             __st_storages_a9uh
             __st_debugCounter_a9ui
             __st_knowledge_a9uk)
     <$> (_f_a9u9 __st_knowledge'_a9uj))
{-# INLINE st_knowledge #-}
st_opEnv ::
  Lens' (F4LState k_a90g s_a90h) OpEnv
st_opEnv
  _f_a9ul
  (F4LState __conf_db_a9um
            __st_verbosity_a9un
            __st_interactive_a9uo
            __st_withExif_a9up
            __st_withRescan_a9uq
            __st_opEnv'_a9ur
            __st_session_a9ut
            __st_storages_a9uu
            __st_debugCounter_a9uv
            __st_knowledge_a9uw)
  = ((\ __st_opEnv_a9us
        -> F4LState
             __conf_db_a9um
             __st_verbosity_a9un
             __st_interactive_a9uo
             __st_withExif_a9up
             __st_withRescan_a9uq
             __st_opEnv_a9us
             __st_session_a9ut
             __st_storages_a9uu
             __st_debugCounter_a9uv
             __st_knowledge_a9uw)
     <$> (_f_a9ul __st_opEnv'_a9ur))
{-# INLINE st_opEnv #-}
st_session ::
  Lens (F4LState k_a90g s_a90h) (F4LState k_a90g s_a9ux) s_a90h s_a9ux
st_session
  _f_a9uy
  (F4LState __conf_db_a9uz
            __st_verbosity_a9uA
            __st_interactive_a9uB
            __st_withExif_a9uC
            __st_withRescan_a9uD
            __st_opEnv_a9uE
            __st_session'_a9uF
            __st_storages_a9uH
            __st_debugCounter_a9uI
            __st_knowledge_a9uJ)
  = ((\ __st_session_a9uG
        -> F4LState
             __conf_db_a9uz
             __st_verbosity_a9uA
             __st_interactive_a9uB
             __st_withExif_a9uC
             __st_withRescan_a9uD
             __st_opEnv_a9uE
             __st_session_a9uG
             __st_storages_a9uH
             __st_debugCounter_a9uI
             __st_knowledge_a9uJ)
     <$> (_f_a9uy __st_session'_a9uF))
{-# INLINE st_session #-}
st_storages ::
  Lens' (F4LState k_a90g s_a90h) (Map FilePath (Maybe StorageId))
st_storages
  _f_a9uK
  (F4LState __conf_db_a9uL
            __st_verbosity_a9uM
            __st_interactive_a9uN
            __st_withExif_a9uO
            __st_withRescan_a9uP
            __st_opEnv_a9uQ
            __st_session_a9uR
            __st_storages'_a9uS
            __st_debugCounter_a9uU
            __st_knowledge_a9uV)
  = ((\ __st_storages_a9uT
        -> F4LState
             __conf_db_a9uL
             __st_verbosity_a9uM
             __st_interactive_a9uN
             __st_withExif_a9uO
             __st_withRescan_a9uP
             __st_opEnv_a9uQ
             __st_session_a9uR
             __st_storages_a9uT
             __st_debugCounter_a9uU
             __st_knowledge_a9uV)
     <$> (_f_a9uK __st_storages'_a9uS))
{-# INLINE st_storages #-}
st_verbosity ::
  Lens' (F4LState k_a90g s_a90h) Verbosity
st_verbosity
  _f_a9uW
  (F4LState __conf_db_a9uX
            __st_verbosity'_a9uY
            __st_interactive_a9v0
            __st_withExif_a9v1
            __st_withRescan_a9v2
            __st_opEnv_a9v3
            __st_session_a9v4
            __st_storages_a9v5
            __st_debugCounter_a9v6
            __st_knowledge_a9v7)
  = ((\ __st_verbosity_a9uZ
        -> F4LState
             __conf_db_a9uX
             __st_verbosity_a9uZ
             __st_interactive_a9v0
             __st_withExif_a9v1
             __st_withRescan_a9v2
             __st_opEnv_a9v3
             __st_session_a9v4
             __st_storages_a9v5
             __st_debugCounter_a9v6
             __st_knowledge_a9v7)
     <$> (_f_a9uW __st_verbosity'_a9uY))
{-# INLINE st_verbosity #-}
st_withExif ::
  Lens' (F4LState k_a90g s_a90h) Bool
st_withExif
  _f_a9v8
  (F4LState __conf_db_a9v9
            __st_verbosity_a9va
            __st_interactive_a9vb
            __st_withExif'_a9vc
            __st_withRescan_a9ve
            __st_opEnv_a9vf
            __st_session_a9vg
            __st_storages_a9vh
            __st_debugCounter_a9vi
            __st_knowledge_a9vj)
  = ((\ __st_withExif_a9vd
        -> F4LState
             __conf_db_a9v9
             __st_verbosity_a9va
             __st_interactive_a9vb
             __st_withExif_a9vd
             __st_withRescan_a9ve
             __st_opEnv_a9vf
             __st_session_a9vg
             __st_storages_a9vh
             __st_debugCounter_a9vi
             __st_knowledge_a9vj)
     <$> (_f_a9v8 __st_withExif'_a9vc))
{-# INLINE st_withExif #-}
st_withRescan ::
  Lens' (F4LState k_a90g s_a90h) Bool
st_withRescan
  _f_a9vk
  (F4LState __conf_db_a9vl
            __st_verbosity_a9vm
            __st_interactive_a9vn
            __st_withExif_a9vo
            __st_withRescan'_a9vp
            __st_opEnv_a9vr
            __st_session_a9vs
            __st_storages_a9vt
            __st_debugCounter_a9vu
            __st_knowledge_a9vv)
  = ((\ __st_withRescan_a9vq
        -> F4LState
             __conf_db_a9vl
             __st_verbosity_a9vm
             __st_interactive_a9vn
             __st_withExif_a9vo
             __st_withRescan_a9vq
             __st_opEnv_a9vr
             __st_session_a9vs
             __st_storages_a9vt
             __st_debugCounter_a9vu
             __st_knowledge_a9vv)
     <$> (_f_a9vk __st_withRescan'_a9vp))
{-# INLINE st_withRescan #-}

==> file4life-1.1.4-source.tgz: file4life-1.1.4/src/F4L/F4LMonad.hs <==
{- This file is part of file4life, a file backup program written in Haskell.
 - file4life is Copyright (C) Antonio Bellezza 2014
 - file4life is free software: you can redistribute it and/or modify
 - it under the terms of the GNU General Public License as published by
 - the Free Software Foundation, either version 3 of the License, or
 - (at your option) any later version.

 - file4life is distributed in the hope that it will be useful,
 - but WITHOUT ANY WARRANTY; without even the implied warranty of
 - MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 - GNU General Public License for more details.

 - You should have received a copy of the GNU General Public License
 - along with file4life.  If not, see <http://www.gnu.org/licenses/>.
 -}
-- {-# LANGUAGE TemplateHaskell #-}

module F4L.F4LMonad where

import F4L
import F4L.Op

import Control.Lens
import Control.Monad.State.Strict
import Data.Functor((<$>))
import Data.Map.Strict( Map )


type GenF4LMonad k s m = StateT ( F4LState k s ) m

type F4LMonad k m = GenF4LMonad k ActiveSession m

type TopF4LMonad k m = GenF4LMonad k () m

data VerbosityLevel = Quiet | Timid | Chatty | SayAll
                    deriving ( Eq, Show, Ord, Enum )

data Verbosity = Verbosity {
    _verb_level :: VerbosityLevel
  , _verb_tracing :: Bool
  } deriving Show


verb_level :: Lens' Verbosity VerbosityLevel
verb_level = lens _verb_level ( \ s a -> s { _verb_level = a } )

verb_tracing :: Lens' Verbosity Bool
verb_tracing = lens _verb_tracing ( \ s a -> s { _verb_tracing = a } )


data Interactivity = Ask | UseDefault | Use String
                   deriving ( Eq, Show )

data ActiveSession = ActiveSession {
    _as_envid :: !EnvironmentId
  , _as_time :: !TimeStamp
  } deriving Show

st_time :: Lens' ( F4LState k ActiveSession ) TimeStamp
st_time = st_session . as_time

st_envid :: Lens' ( F4LState k ActiveSession ) EnvironmentId
st_envid = st_session . as_envid

-- makeLenses ''ActiveSession

as_envid :: Lens' ActiveSession EnvironmentId
as_envid = lens _as_envid ( \ s a -> s { _as_envid = a } )
{-# INLINE as_envid #-}
as_time :: Lens' ActiveSession TimeStamp
as_time = lens _as_time ( \ s a -> s { _as_time = a } )
{-# INLINE as_time #-}



data F4LState k s = F4LState { 
    _conf_db :: !MetaDB
  , _st_verbosity :: !Verbosity
  , _st_interactive :: !Interactivity
  , _st_withExif :: !Bool
  , _st_withRescan :: !Bool
  , _st_opEnv :: !OpEnv
  , _st_session :: s
  , _st_storages :: !(Map FilePath ( Maybe StorageId )) -- ^ for current session
  , _st_debugCounter :: !Int -- ^ to activate behaviours every n iterations
  , _st_knowledge :: !k
  } deriving Show

-- makeLenses ''F4LState

conf_db ::
  Lens' (F4LState k_a90g s_a90h) MetaDB
conf_db
  _f_a9ty
  (F4LState __conf_db'_a9tz
            __st_verbosity_a9tB
            __st_interactive_a9tC
            __st_withExif_a9tD
            __st_withRescan_a9tE
            __st_opEnv_a9tF
            __st_session_a9tG
            __st_storages_a9tH
            __st_debugCounter_a9tI
            __st_knowledge_a9tJ)
  = ((\ __conf_db_a9tA
        -> F4LState
             __conf_db_a9tA
             __st_verbosity_a9tB
             __st_interactive_a9tC
             __st_withExif_a9tD
             __st_withRescan_a9tE
             __st_opEnv_a9tF
             __st_session_a9tG
             __st_storages_a9tH
             __st_debugCounter_a9tI
             __st_knowledge_a9tJ)
     <$> (_f_a9ty __conf_db'_a9tz))
{-# INLINE conf_db #-}
st_debugCounter ::
  Lens' (F4LState k_a90g s_a90h) Int
st_debugCounter
  _f_a9tK
  (F4LState __conf_db_a9tL
            __st_verbosity_a9tM
            __st_interactive_a9tN
            __st_withExif_a9tO
            __st_withRescan_a9tP
            __st_opEnv_a9tQ
            __st_session_a9tR
            __st_storages_a9tS
            __st_debugCounter'_a9tT
            __st_knowledge_a9tV)
  = ((\ __st_debugCounter_a9tU
        -> F4LState
             __conf_db_a9tL
             __st_verbosity_a9tM
             __st_interactive_a9tN
             __st_withExif_a9tO
             __st_withRescan_a9tP
             __st_opEnv_a9tQ
             __st_session_a9tR
             __st_storages_a9tS
             __st_debugCounter_a9tU
             __st_knowledge_a9tV)
     <$> (_f_a9tK __st_debugCounter'_a9tT))
{-# INLINE st_debugCounter #-}
st_interactive ::
  Lens' (F4LState k_a90g s_a90h) Interactivity
st_interactive
  _f_a9tW
  (F4LState __conf_db_a9tX
            __st_verbosity_a9tY
            __st_interactive'_a9tZ
            __st_withExif_a9u1
            __st_withRescan_a9u2
            __st_opEnv_a9u3
            __st_session_a9u4
            __st_storages_a9u5
            __st_debugCounter_a9u6
            __st_knowledge_a9u7)
  = ((\ __st_interactive_a9u0
        -> F4LState
             __conf_db_a9tX
             __st_verbosity_a9tY
             __st_interactive_a9u0
             __st_withExif_a9u1
             __st_withRescan_a9u2
             __st_opEnv_a9u3
             __st_session_a9u4
             __st_storages_a9u5
             __st_debugCounter_a9u6
             __st_knowledge_a9u7)
     <$> (_f_a9tW __st_interactive'_a9tZ))
{-# INLINE st_interactive #-}
st_knowledge ::
  Lens (F4LState k_a90g s_a90h) (F4LState k_a9u8 s_a90h) k_a90g k_a9u8
st_knowledge
  _f_a9u9
  (F4LState __conf_db_a9ua
            __st_verbosity_a9ub
            __st_interactive_a9uc
            __st_withExif_a9ud
            __st_withRescan_a9ue
            __st_opEnv_a9uf
            __st_session_a9ug
            __st_storages_a9uh
            __st_debugCounter_a9ui
            __st_knowledge'_a9uj)
  = ((\ __st_knowledge_a9uk
        -> F4LState
             __conf_db_a9ua
             __st_verbosity_a9ub
             __st_interactive_a9uc
             __st_withExif_a9ud
             __st_withRescan_a9ue
             __st_opEnv_a9uf
             __st_session_a9ug
             __st_storages_a9uh
             __st_debugCounter_a9ui
             __st_knowledge_a9uk)
     <$> (_f_a9u9 __st_knowledge'_a9uj))
{-# INLINE st_knowledge #-}
st_opEnv ::
  Lens' (F4LState k_a90g s_a90h) OpEnv
st_opEnv
  _f_a9ul
  (F4LState __conf_db_a9um
            __st_verbosity_a9un
            __st_interactive_a9uo
            __st_withExif_a9up
            __st_withRescan_a9uq
            __st_opEnv'_a9ur
            __st_session_a9ut
            __st_storages_a9uu
            __st_debugCounter_a9uv
            __st_knowledge_a9uw)
  = ((\ __st_opEnv_a9us
        -> F4LState
             __conf_db_a9um
             __st_verbosity_a9un
             __st_interactive_a9uo
             __st_withExif_a9up
             __st_withRescan_a9uq
             __st_opEnv_a9us
             __st_session_a9ut
             __st_storages_a9uu
             __st_debugCounter_a9uv
             __st_knowledge_a9uw)
     <$> (_f_a9ul __st_opEnv'_a9ur))
{-# INLINE st_opEnv #-}
st_session ::
  Lens (F4LState k_a90g s_a90h) (F4LState k_a90g s_a9ux) s_a90h s_a9ux
st_session
  _f_a9uy
  (F4LState __conf_db_a9uz
            __st_verbosity_a9uA
            __st_interactive_a9uB
            __st_withExif_a9uC
            __st_withRescan_a9uD
            __st_opEnv_a9uE
            __st_session'_a9uF
            __st_storages_a9uH
            __st_debugCounter_a9uI
            __st_knowledge_a9uJ)
  = ((\ __st_session_a9uG
        -> F4LState
             __conf_db_a9uz
             __st_verbosity_a9uA
             __st_interactive_a9uB
             __st_withExif_a9uC
             __st_withRescan_a9uD
             __st_opEnv_a9uE
             __st_session_a9uG
             __st_storages_a9uH
             __st_debugCounter_a9uI
             __st_knowledge_a9uJ)
     <$> (_f_a9uy __st_session'_a9uF))
{-# INLINE st_session #-}
st_storages ::
  Lens' (F4LState k_a90g s_a90h) (Map FilePath (Maybe StorageId))
st_storages
  _f_a9uK
  (F4LState __conf_db_a9uL
            __st_verbosity_a9uM
            __st_interactive_a9uN
            __st_withExif_a9uO
            __st_withRescan_a9uP
            __st_opEnv_a9uQ
            __st_session_a9uR
            __st_storages'_a9uS
            __st_debugCounter_a9uU
            __st_knowledge_a9uV)
  = ((\ __st_storages_a9uT
        -> F4LState
             __conf_db_a9uL
             __st_verbosity_a9uM
             __st_interactive_a9uN
             __st_withExif_a9uO
             __st_withRescan_a9uP
             __st_opEnv_a9uQ
             __st_session_a9uR
             __st_storages_a9uT
             __st_debugCounter_a9uU
             __st_knowledge_a9uV)
     <$> (_f_a9uK __st_storages'_a9uS))
{-# INLINE st_storages #-}
st_verbosity ::
  Lens' (F4LState k_a90g s_a90h) Verbosity
st_verbosity
  _f_a9uW
  (F4LState __conf_db_a9uX
            __st_verbosity'_a9uY
            __st_interactive_a9v0
            __st_withExif_a9v1
            __st_withRescan_a9v2
            __st_opEnv_a9v3
            __st_session_a9v4
            __st_storages_a9v5
            __st_debugCounter_a9v6
            __st_knowledge_a9v7)
  = ((\ __st_verbosity_a9uZ
        -> F4LState
             __conf_db_a9uX
             __st_verbosity_a9uZ
             __st_interactive_a9v0
             __st_withExif_a9v1
             __st_withRescan_a9v2
             __st_opEnv_a9v3
             __st_session_a9v4
             __st_storages_a9v5
             __st_debugCounter_a9v6
             __st_knowledge_a9v7)
     <$> (_f_a9uW __st_verbosity'_a9uY))
{-# INLINE st_verbosity #-}
st_withExif ::
  Lens' (F4LState k_a90g s_a90h) Bool
st_withExif
  _f_a9v8
  (F4LState __conf_db_a9v9
            __st_verbosity_a9va
            __st_interactive_a9vb
            __st_withExif'_a9vc
            __st_withRescan_a9ve
            __st_opEnv_a9vf
            __st_session_a9vg
            __st_storages_a9vh
            __st_debugCounter_a9vi
            __st_knowledge_a9vj)
  = ((\ __st_withExif_a9vd
        -> F4LState
             __conf_db_a9v9
             __st_verbosity_a9va
             __st_interactive_a9vb
             __st_withExif_a9vd
             __st_withRescan_a9ve
             __st_opEnv_a9vf
             __st_session_a9vg
             __st_storages_a9vh
             __st_debugCounter_a9vi
             __st_knowledge_a9vj)
     <$> (_f_a9v8 __st_withExif'_a9vc))
{-# INLINE st_withExif #-}
st_withRescan ::
  Lens' (F4LState k_a90g s_a90h) Bool
st_withRescan
  _f_a9vk
  (F4LState __conf_db_a9vl
            __st_verbosity_a9vm
            __st_interactive_a9vn
            __st_withExif_a9vo
            __st_withRescan'_a9vp
            __st_opEnv_a9vr
            __st_session_a9vs
            __st_storages_a9vt
            __st_debugCounter_a9vu
            __st_knowledge_a9vv)
  = ((\ __st_withRescan_a9vq
        -> F4LState
             __conf_db_a9vl
             __st_verbosity_a9vm
             __st_interactive_a9vn
             __st_withExif_a9vo
             __st_withRescan_a9vq
             __st_opEnv_a9vr
             __st_session_a9vs
             __st_storages_a9vt
             __st_debugCounter_a9vu
             __st_knowledge_a9vv)
     <$> (_f_a9vk __st_withRescan'_a9vp))
{-# INLINE st_withRescan #-}
